@@ -4,14 +4,13 @@ import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
-import pylab, matplotlib
+import matplotlib
 import os.path
 import pickle
-from sklearn.linear_model import Lasso
 from sklearn.decomposition import PCA
 from sklearn.cross_decomposition import PLSRegression
-from ..data import SMOTE,GAN
 from . import pre
+from .aug import upsample
 from ..dr import lda
 
 from ..vis import *
@@ -23,7 +22,7 @@ DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False ,'7341_C1 desc.txt', ['S
 's4_formula_c3': ('7341.csv', ',', True ,'7341 desc.txt', ['Brand 1', 'Brand 2', 'Brand 3']),
 'milk_tablet_candy': ('734b.csv',',', False,'734b desc.txt', None),
 'yogurt': ('7346.csv',',', True,'7346 desc.txt', ["YL","GM","WQ","MN"]),
-'vintage': ('7344.txt','\t', False,'7344 desc.txt', '8-year vintage'),
+'vintage': ('7344.txt','\t', False,'7344 desc.txt', ['8-year vintage']),
 'vintage_spi': ('7345.csv',',', True,'7345 desc.txt', ["5Y","8Y","16Y","26Y"]),
 'vintage_c2': ('7344_C03.csv',',',True,'7344_C03 desc.txt',["5Y","26Y"]),
 'beimu': ('754a_C2S_Beimu.txt',',', True,'754a_C2S_Beimu desc.txt',["Sichuan","Zhejiang"]),
@@ -35,13 +34,17 @@ DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False ,'7341_C1 desc.txt', ['S
 'cheese': ('Cheese_RAMAN.csv',',',True,'Cheese_RAMAN desc.txt',['MK','SL','YL']),
 'huangjing': ('7a43.csv',',',True,'7a43 desc.txt',['Wild','Cultivated']),
 'huangjing2': ('7a47.csv',',',True,'7a47 desc.txt',['Red-Stem','Green-Stem']),
-'chaihu': ('7a41.csv',',',True,'7a41 desc.txt',['Wild','Cultivated','B. smithii Wolff','Gansu','Shanxi','vinegar Concocted','Terrestrosin D']),
+'chaihu_rm': ('7a41.csv',',',True,'7a41 desc.txt',['Wild','Cultivated','B. smithii Wolff','Gansu','Shanxi','vinegar Concocted','Terrestrosin D']),
 'rice_cereal':('7741_rice_cereal_rm.csv',',',True,'7741_rice_cereal_rm desc.txt', ['LF','EB']),
 'organic_milk': ('MALDITOFMS_ORGANICMILK_7047_C02.csv',',',True,'MALDITOFMS_ORGANICMILK_7047_C02 desc.txt', ['inorganic','organic']),
 'milkpowder_enose': ('7747.pkl',',',True,'7747 desc.txt', ['cn','au']),
 #'forsythia': ('7746.pkl',',',True,'7746 desc.txt', ["SX山西","HN河南","HB湖北","SHX陕西"]) # 该电子鼻数据未有效对齐
 'milkpowder_etongue': ('7744.pkl',',',True,'7744 desc.txt', ['cn','au']),
-'forsythia_etongue': ('7745.pkl',',',True,'7745 desc.txt', ["SX山西","HN河南","HB湖北","SHX陕西"]) # 该电子鼻数据未有效对齐
+'forsythia_etongue': ('7745.pkl',',',True,'7745 desc.txt', ["SX山西","HN河南","HB湖北","SHX陕西"]), # 该电子鼻数据未有效对齐
+'yimi_rm': ('yimi_raman.csv',',',False,'yimi_raman desc.txt',['coix seed']),
+'hangbaiju_rm': ('hangbaiju_raman.csv',',',False,'hangbaiju_raman desc.txt', ['chrysanthemum morifolium']),
+'salt': ('7545.csv',',',True,'7545 desc.txt',["well salt", "sea salt"]),
+'chaihu_ms': ('7b43.csv',',',True,'7b43 desc.txt',["wild","cultivated"])
 }
 
 def get_available_datasets():
@@ -141,6 +144,8 @@ def open_dataset(path, delimiter = ',', has_y = True, x_range = None, y_subset=N
         X = np.array(Xs)
         y = np.array(ys)
 
+    print('X.shape',X.shape, ' y.shape',y.shape)
+
     cnt_nan = np.isnan (X).sum()
     if cnt_nan > 0:
         print('Found' + str(cnt_nan) + 'NaN elements in X. You may need to purge NaN.')
@@ -155,7 +160,7 @@ def scatter_plot(X, y, labels = None):
     plt.title('PCA')
     plt.show()
 
-    if y is not None:
+    if y is not None and X.shape[1] < 6000: # for very-high dimensional data, lda/pls is very slow.
 
         X_lda = lda(X,y)
         plotComponents2D(X_lda, y, legends = labels) # , tags = range(len(y)), ax = ax   
@@ -195,9 +200,12 @@ def draw_average (X, X_names, SD = 1):
 
     matplotlib.rcParams.update({'font.size': 12})
 
-
-def draw_all (X, y, X_names, titles = None, bdr = False):
+def draw_samples (X, y, X_names, titles = None, bdr = False):
     '''
+    To draw the first K samples, call like this: draw_samples(X[:K], y[:K]...
+
+    Parameters
+    ----------    
     bdr : baseline drift removal using Butterworth high-pass filter
     '''
 
@@ -226,7 +234,7 @@ def draw_all (X, y, X_names, titles = None, bdr = False):
             plt.plot(X_names, xbdr, linewidth=1, label='baseline drift removal')
 
         plt.title(title)
-        plt.yticks([])
+        # plt.yticks([])
         plt.legend()
         plt.show()
 
@@ -324,33 +332,13 @@ def peek_dataset(path,  delimiter = ',', has_y = True, labels = None, SD = 1, sh
 
     return X, y, X_names
 
+'''
 def upsample(target_path, X, y, X_names, method = 'SMOTE', folds = 3, d = 0.5, 
 epochs = 10, batch_size = 100, cuda = True, display = False, verbose = True):
-    '''
-    Upsample a dataset by SMOTE or GAN.
-
-    Parameters
-    ----------
-    X_names : the labels for each X feature
-    folds : expand to N folds
-    d : sampling distance in SMOTE
-    epochs, batch_size, cuda : ctgan params
-    '''
-
-    if method == 'SMOTE':
-        Xn, yn = SMOTE.expand_dataset(X, y, X_names, target_path, d, folds)
-    elif method == 'GAN':
-        Xn, yn = GAN.expand_dataset(X, y, X_names, target_path, folds, epochs, batch_size, cuda, verbose)
-
-    if display:      
-
-        pca = PCA(n_components=2) # keep the first 2 components
-        X_pca = pca.fit_transform(Xn)
-        plotComponents2D(X_pca, yn)
-        plt.title('PCA of extended dataset')
-        plt.show()
-
-    return Xn, yn
+    
+    return upsample(target_path, X, y, X_names, method, folds, d, 
+epochs, batch_size, cuda, display, verbose)
+'''
 
 def save_dataset(targe_path, X, y, X_names):
     '''
